#[repr(u8)]pub enum MajorDeviceId {
Show 13 variants
W25_05 = 5,
W25_10 = 16,
W25_20 = 17,
W25_40 = 18,
W25_80 = 19,
W25_16 = 20,
W25_32 = 21,
W25_64 = 22,
W25_128 = 23,
W25_256 = 24,
W25_512 = 25,
W25_01 = 32,
W25_02 = 33,
}Expand description
Major byte of the device identification (ID7-ID0) denoting chip capacity.
Note that the repr value corresponds to the Manufacturer/DeviceID command (0x90) and not the JEDEC ID (0x9F). The latter is the same value, but incremented by one (with exception of W25_512, which is incremented by seven).
Variants
W25_05 = 5
W25X10 512kb device
W25_10 = 16
W25[QX]10 1Mb device
W25_20 = 17
W25[QX]20 2Mb device
W25_40 = 18
W25[QX]40 4Mb device
W25_80 = 19
W25[QX]80 8Mb device
W25_16 = 20
W25[QX]16 16Mb device
W25_32 = 21
W25[QX]32 32Mb device
W25_64 = 22
W25[QX]64 64Mb device
W25_128 = 23
W25Q128 128Mb device
W25_256 = 24
W25Q256 256Mb device
W25_512 = 25
W25Q512 512Mb device
W25_01 = 32
W25Q01 1Gb device
W25_02 = 33
W25Q02 2Gb device
Implementations